import React, { useState } from "react";
import LoginCard from "./LoginCard";
import { useToast } from "../../../hooks";
import { useTranslation } from "react-i18next";
import LoggedInComponent from "./LoggedInComponent";
import { useTuitioClient, useTuitioToken } from "@flare/tuitio-client-react";

const LoginContainer = () => {
  const [credentials, setCredentials] = useState({
    userName: "",
    password: ""
  });

  const { error } = useToast();
  const { t } = useTranslation();
  const { login, logout } = useTuitioClient({
    onLoginFailed: () => error(t("Login.IncorrectCredentials")),
    onLoginError: err => error(err.message)
  });
  const { valid: tokenIsValid } = useTuitioToken();

  const handleChange = prop => event => {
    setCredentials(prev => ({ ...prev, [prop]: event.target.value }));
  };

  const handleLogin = () => {
    const { userName, password } = credentials;
    return login(userName, password);
  };

  const handleLogout = () => {
    logout();
  };

  return (
    <>
      {tokenIsValid ? (
        <LoggedInComponent
          credentials={credentials}
          onChange={handleChange}
          onLogin={handleLogin}
          onLogout={handleLogout}
        />
      ) : (
        <LoginCard
          credentials={credentials}
          onChange={handleChange}
          onLogin={handleLogin}
        />
      )}
    </>
  );
};

export default LoginContainer;
